@@ -22,8 +22,6 @@
 
 #include <stdint.h>
 
-#define SUPPORTED_MUTTER_SCREEN_CAST_API_VERSION 2
-
 enum
 {
   STREAM_SIGNAL_READY,
@@ -59,6 +57,8 @@ typedef struct _GnomeScreenCastStream
 
   GnomeScreenCastSession *session;
 
+  ScreenCastSourceType source_type;
+
   char *path;
   OrgGnomeMutterScreenCastStream *proxy;
 
@@ -234,6 +234,10 @@ gnome_screen_cast_session_add_stream_properties (GnomeScreenCastSession *gnome_s
 
       g_variant_builder_init (&stream_properties_builder, G_VARIANT_TYPE_VARDICT);
 
+      g_variant_builder_add (&stream_properties_builder, "{sv}",
+                             "source_type",
+                             g_variant_new ("u", stream->source_type));
+
       if (gnome_screen_cast_stream_get_position (stream, &x, &y))
         g_variant_builder_add (&stream_properties_builder, "{sv}",
                                "position",
@@ -319,6 +323,7 @@ gnome_screen_cast_session_record_window (GnomeScreenCastSession *gnome_screen_ca
     return FALSE;
 
   stream = g_object_new (gnome_screen_cast_stream_get_type (), NULL);
+  stream->source_type = SCREEN_CAST_SOURCE_TYPE_WINDOW;
   stream->session = gnome_screen_cast_session;
   stream->path = g_strdup (stream_path);
   stream->proxy = stream_proxy;
@@ -398,6 +403,7 @@ gnome_screen_cast_session_record_monitor (GnomeScreenCastSession *gnome_screen_c
     return FALSE;
 
   stream = g_object_new (gnome_screen_cast_stream_get_type (), NULL);
+  stream->source_type = SCREEN_CAST_SOURCE_TYPE_MONITOR;
   stream->session = gnome_screen_cast_session;
   stream->path = g_strdup (stream_path);
   stream->proxy = stream_proxy;
@@ -635,12 +641,6 @@ gnome_screen_cast_name_appeared (GDBusConnection *connection,
 
   gnome_screen_cast->api_version =
     org_gnome_mutter_screen_cast_get_version (gnome_screen_cast->proxy);
-  if (gnome_screen_cast->api_version > SUPPORTED_MUTTER_SCREEN_CAST_API_VERSION)
-    {
-      g_warning ("org.gnome.Mutter.ScreenCast API version not compatible");
-      g_clear_object (&gnome_screen_cast->proxy);
-      return;
-    }
 
   g_signal_emit (gnome_screen_cast, signals[ENABLED], 0);
 }
