@@ -35,8 +35,6 @@
 #include "session.h"
 #include "utils.h"
 
-#define SUPPORTED_MUTTER_SCREEN_CAST_API_VERSION 2
-
 typedef struct _ScreenCastDialogHandle ScreenCastDialogHandle;
 
 typedef struct _ScreenCastSession
@@ -415,7 +413,6 @@ start_session (ScreenCastSession *screen_cast_session,
                GError **error)
 {
   GnomeScreenCastSession *gnome_screen_cast_session;
-  int gnome_api_version;
   g_autoptr(GVariant) source_selections = NULL;
 
   gnome_screen_cast_session =
@@ -423,18 +420,6 @@ start_session (ScreenCastSession *screen_cast_session,
   if (!gnome_screen_cast_session)
     return FALSE;
 
-  gnome_api_version = gnome_screen_cast_get_api_version (gnome_screen_cast);
-  if (gnome_api_version < SUPPORTED_MUTTER_SCREEN_CAST_API_VERSION)
-    {
-      g_set_error (error, XDG_DESKTOP_PORTAL_ERROR,
-                   XDG_DESKTOP_PORTAL_ERROR_FAILED,
-                   "org.gnome.Mutter.ScreenCast API version %d lower "
-                   "than minimum supported version %d",
-                   gnome_api_version, SUPPORTED_MUTTER_SCREEN_CAST_API_VERSION);
-      g_clear_object (&gnome_screen_cast);
-      return FALSE;
-    }
-
   screen_cast_session->gnome_screen_cast_session = gnome_screen_cast_session;
 
   screen_cast_session->session_ready_handler_id =
